dhcpkit.ipv6.server.extensions package
======================================

.. automodule:: dhcpkit.ipv6.server.extensions
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    dhcpkit.ipv6.server.extensions.dns
    dhcpkit.ipv6.server.extensions.ntp
    dhcpkit.ipv6.server.extensions.remote_id
    dhcpkit.ipv6.server.extensions.sip_servers
    dhcpkit.ipv6.server.extensions.sntp
    dhcpkit.ipv6.server.extensions.sol_max_rt
    dhcpkit.ipv6.server.extensions.static_assignments
    dhcpkit.ipv6.server.extensions.timing_limits

Submodules
----------

.. toctree::

   dhcpkit.ipv6.server.extensions.prefix_delegation

